@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,10 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.translate import gapic_version as package_version
+
+__version__ = package_version.__version__
+
 
 from .services.translation_service import TranslationServiceClient
 from .services.translation_service import TranslationServiceAsyncClient
 
+from .types.translation_service import BatchDocumentInputConfig
+from .types.translation_service import BatchDocumentOutputConfig
+from .types.translation_service import BatchTranslateDocumentMetadata
+from .types.translation_service import BatchTranslateDocumentRequest
+from .types.translation_service import BatchTranslateDocumentResponse
 from .types.translation_service import BatchTranslateMetadata
 from .types.translation_service import BatchTranslateResponse
 from .types.translation_service import BatchTranslateTextRequest
@@ -28,6 +37,9 @@ from .types.translation_service import DeleteGlossaryResponse
 from .types.translation_service import DetectedLanguage
 from .types.translation_service import DetectLanguageRequest
 from .types.translation_service import DetectLanguageResponse
+from .types.translation_service import DocumentInputConfig
+from .types.translation_service import DocumentOutputConfig
+from .types.translation_service import DocumentTranslation
 from .types.translation_service import GcsDestination
 from .types.translation_service import GcsSource
 from .types.translation_service import GetGlossaryRequest
@@ -40,6 +52,8 @@ from .types.translation_service import ListGlossariesResponse
 from .types.translation_service import OutputConfig
 from .types.translation_service import SupportedLanguage
 from .types.translation_service import SupportedLanguages
+from .types.translation_service import TranslateDocumentRequest
+from .types.translation_service import TranslateDocumentResponse
 from .types.translation_service import TranslateTextGlossaryConfig
 from .types.translation_service import TranslateTextRequest
 from .types.translation_service import TranslateTextResponse
@@ -47,6 +61,11 @@ from .types.translation_service import Translation
 
 __all__ = (
     "TranslationServiceAsyncClient",
+    "BatchDocumentInputConfig",
+    "BatchDocumentOutputConfig",
+    "BatchTranslateDocumentMetadata",
+    "BatchTranslateDocumentRequest",
+    "BatchTranslateDocumentResponse",
     "BatchTranslateMetadata",
     "BatchTranslateResponse",
     "BatchTranslateTextRequest",
@@ -58,6 +77,9 @@ __all__ = (
     "DetectLanguageRequest",
     "DetectLanguageResponse",
     "DetectedLanguage",
+    "DocumentInputConfig",
+    "DocumentOutputConfig",
+    "DocumentTranslation",
     "GcsDestination",
     "GcsSource",
     "GetGlossaryRequest",
@@ -70,6 +92,8 @@ __all__ = (
     "OutputConfig",
     "SupportedLanguage",
     "SupportedLanguages",
+    "TranslateDocumentRequest",
+    "TranslateDocumentResponse",
     "TranslateTextGlossaryConfig",
     "TranslateTextRequest",
     "TranslateTextResponse",
