@@ -16,8 +16,19 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
+
+from google.cloud.translate_v3beta1 import gapic_version as package_version
 
 from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
@@ -162,9 +173,9 @@ class TranslationServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, TranslationServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the translation service client.
@@ -208,16 +219,23 @@ class TranslationServiceAsyncClient:
 
     async def translate_text(
         self,
-        request: Union[translation_service.TranslateTextRequest, dict] = None,
+        request: Optional[Union[translation_service.TranslateTextRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> translation_service.TranslateTextResponse:
         r"""Translates input text and returns translated text.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import translate_v3beta1
 
             async def sample_translate_text():
@@ -226,7 +244,7 @@ class TranslationServiceAsyncClient:
 
                 # Initialize request argument(s)
                 request = translate_v3beta1.TranslateTextRequest(
-                    contents=['contents_value_1', 'contents_value_2'],
+                    contents=['contents_value1', 'contents_value2'],
                     target_language_code="target_language_code_value",
                     parent="parent_value",
                 )
@@ -238,7 +256,7 @@ class TranslationServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.translate_v3beta1.types.TranslateTextRequest, dict]):
+            request (Optional[Union[google.cloud.translate_v3beta1.types.TranslateTextRequest, dict]]):
                 The request object. The request message for synchronous
                 translation.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -281,19 +299,28 @@ class TranslationServiceAsyncClient:
 
     async def detect_language(
         self,
-        request: Union[translation_service.DetectLanguageRequest, dict] = None,
+        request: Optional[
+            Union[translation_service.DetectLanguageRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        model: str = None,
-        mime_type: str = None,
+        parent: Optional[str] = None,
+        model: Optional[str] = None,
+        mime_type: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> translation_service.DetectLanguageResponse:
         r"""Detects the language of text within a request.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import translate_v3beta1
 
             async def sample_detect_language():
@@ -313,7 +340,7 @@ class TranslationServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.translate_v3beta1.types.DetectLanguageRequest, dict]):
+            request (Optional[Union[google.cloud.translate_v3beta1.types.DetectLanguageRequest, dict]]):
                 The request object. The request message for language
                 detection.
             parent (:class:`str`):
@@ -419,13 +446,15 @@ class TranslationServiceAsyncClient:
 
     async def get_supported_languages(
         self,
-        request: Union[translation_service.GetSupportedLanguagesRequest, dict] = None,
+        request: Optional[
+            Union[translation_service.GetSupportedLanguagesRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        display_language_code: str = None,
-        model: str = None,
+        parent: Optional[str] = None,
+        display_language_code: Optional[str] = None,
+        model: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> translation_service.SupportedLanguages:
         r"""Returns a list of supported languages for
@@ -433,6 +462,13 @@ class TranslationServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import translate_v3beta1
 
             async def sample_get_supported_languages():
@@ -451,7 +487,7 @@ class TranslationServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.translate_v3beta1.types.GetSupportedLanguagesRequest, dict]):
+            request (Optional[Union[google.cloud.translate_v3beta1.types.GetSupportedLanguagesRequest, dict]]):
                 The request object. The request message for discovering
                 supported languages.
             parent (:class:`str`):
@@ -572,16 +608,25 @@ class TranslationServiceAsyncClient:
 
     async def translate_document(
         self,
-        request: Union[translation_service.TranslateDocumentRequest, dict] = None,
+        request: Optional[
+            Union[translation_service.TranslateDocumentRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> translation_service.TranslateDocumentResponse:
         r"""Translates documents in synchronous mode.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import translate_v3beta1
 
             async def sample_translate_document():
@@ -605,7 +650,7 @@ class TranslationServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.translate_v3beta1.types.TranslateDocumentRequest, dict]):
+            request (Optional[Union[google.cloud.translate_v3beta1.types.TranslateDocumentRequest, dict]]):
                 The request object. A document translation request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -649,10 +694,12 @@ class TranslationServiceAsyncClient:
 
     async def batch_translate_text(
         self,
-        request: Union[translation_service.BatchTranslateTextRequest, dict] = None,
+        request: Optional[
+            Union[translation_service.BatchTranslateTextRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Translates a large volume of text in asynchronous
@@ -667,6 +714,13 @@ class TranslationServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import translate_v3beta1
 
             async def sample_batch_translate_text():
@@ -683,7 +737,7 @@ class TranslationServiceAsyncClient:
                 request = translate_v3beta1.BatchTranslateTextRequest(
                     parent="parent_value",
                     source_language_code="source_language_code_value",
-                    target_language_codes=['target_language_codes_value_1', 'target_language_codes_value_2'],
+                    target_language_codes=['target_language_codes_value1', 'target_language_codes_value2'],
                     input_configs=input_configs,
                     output_config=output_config,
                 )
@@ -693,13 +747,13 @@ class TranslationServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.translate_v3beta1.types.BatchTranslateTextRequest, dict]):
+            request (Optional[Union[google.cloud.translate_v3beta1.types.BatchTranslateTextRequest, dict]]):
                 The request object. The batch translation request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -755,15 +809,19 @@ class TranslationServiceAsyncClient:
 
     async def batch_translate_document(
         self,
-        request: Union[translation_service.BatchTranslateDocumentRequest, dict] = None,
+        request: Optional[
+            Union[translation_service.BatchTranslateDocumentRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        source_language_code: str = None,
-        target_language_codes: Sequence[str] = None,
-        input_configs: Sequence[translation_service.BatchDocumentInputConfig] = None,
-        output_config: translation_service.BatchDocumentOutputConfig = None,
+        parent: Optional[str] = None,
+        source_language_code: Optional[str] = None,
+        target_language_codes: Optional[MutableSequence[str]] = None,
+        input_configs: Optional[
+            MutableSequence[translation_service.BatchDocumentInputConfig]
+        ] = None,
+        output_config: Optional[translation_service.BatchDocumentOutputConfig] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Translates a large volume of documents in
@@ -778,6 +836,13 @@ class TranslationServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import translate_v3beta1
 
             async def sample_batch_translate_document():
@@ -794,7 +859,7 @@ class TranslationServiceAsyncClient:
                 request = translate_v3beta1.BatchTranslateDocumentRequest(
                     parent="parent_value",
                     source_language_code="source_language_code_value",
-                    target_language_codes=['target_language_codes_value_1', 'target_language_codes_value_2'],
+                    target_language_codes=['target_language_codes_value1', 'target_language_codes_value2'],
                     input_configs=input_configs,
                     output_config=output_config,
                 )
@@ -804,13 +869,13 @@ class TranslationServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.translate_v3beta1.types.BatchTranslateDocumentRequest, dict]):
+            request (Optional[Union[google.cloud.translate_v3beta1.types.BatchTranslateDocumentRequest, dict]]):
                 The request object. The BatchTranslateDocument request.
             parent (:class:`str`):
                 Required. Location to make a regional call.
@@ -839,7 +904,7 @@ class TranslationServiceAsyncClient:
                 This corresponds to the ``source_language_code`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            target_language_codes (:class:`Sequence[str]`):
+            target_language_codes (:class:`MutableSequence[str]`):
                 Required. The BCP-47 language code to
                 use for translation of the input
                 document. Specify up to 10 language
@@ -848,7 +913,7 @@ class TranslationServiceAsyncClient:
                 This corresponds to the ``target_language_codes`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            input_configs (:class:`Sequence[google.cloud.translate_v3beta1.types.BatchDocumentInputConfig]`):
+            input_configs (:class:`MutableSequence[google.cloud.translate_v3beta1.types.BatchDocumentInputConfig]`):
                 Required. Input configurations.
                 The total number of files matched should
                 be <= 100. The total content size to
@@ -953,12 +1018,14 @@ class TranslationServiceAsyncClient:
 
     async def create_glossary(
         self,
-        request: Union[translation_service.CreateGlossaryRequest, dict] = None,
+        request: Optional[
+            Union[translation_service.CreateGlossaryRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        glossary: translation_service.Glossary = None,
+        parent: Optional[str] = None,
+        glossary: Optional[translation_service.Glossary] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a glossary and returns the long-running operation.
@@ -966,6 +1033,13 @@ class TranslationServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import translate_v3beta1
 
             async def sample_create_glossary():
@@ -986,13 +1060,13 @@ class TranslationServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.translate_v3beta1.types.CreateGlossaryRequest, dict]):
+            request (Optional[Union[google.cloud.translate_v3beta1.types.CreateGlossaryRequest, dict]]):
                 The request object. Request message for CreateGlossary.
             parent (:class:`str`):
                 Required. The project name.
@@ -1073,12 +1147,14 @@ class TranslationServiceAsyncClient:
 
     async def list_glossaries(
         self,
-        request: Union[translation_service.ListGlossariesRequest, dict] = None,
+        request: Optional[
+            Union[translation_service.ListGlossariesRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        filter: str = None,
+        parent: Optional[str] = None,
+        filter: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListGlossariesAsyncPager:
         r"""Lists glossaries in a project. Returns NOT_FOUND, if the project
@@ -1086,6 +1162,13 @@ class TranslationServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import translate_v3beta1
 
             async def sample_list_glossaries():
@@ -1105,7 +1188,7 @@ class TranslationServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.translate_v3beta1.types.ListGlossariesRequest, dict]):
+            request (Optional[Union[google.cloud.translate_v3beta1.types.ListGlossariesRequest, dict]]):
                 The request object. Request message for ListGlossaries.
             parent (:class:`str`):
                 Required. The name of the project
@@ -1228,11 +1311,11 @@ class TranslationServiceAsyncClient:
 
     async def get_glossary(
         self,
-        request: Union[translation_service.GetGlossaryRequest, dict] = None,
+        request: Optional[Union[translation_service.GetGlossaryRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> translation_service.Glossary:
         r"""Gets a glossary. Returns NOT_FOUND, if the glossary doesn't
@@ -1240,6 +1323,13 @@ class TranslationServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import translate_v3beta1
 
             async def sample_get_glossary():
@@ -1258,7 +1348,7 @@ class TranslationServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.translate_v3beta1.types.GetGlossaryRequest, dict]):
+            request (Optional[Union[google.cloud.translate_v3beta1.types.GetGlossaryRequest, dict]]):
                 The request object. Request message for GetGlossary.
             name (:class:`str`):
                 Required. The name of the glossary to
@@ -1333,11 +1423,13 @@ class TranslationServiceAsyncClient:
 
     async def delete_glossary(
         self,
-        request: Union[translation_service.DeleteGlossaryRequest, dict] = None,
+        request: Optional[
+            Union[translation_service.DeleteGlossaryRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a glossary, or cancels glossary construction if the
@@ -1346,6 +1438,13 @@ class TranslationServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import translate_v3beta1
 
             async def sample_delete_glossary():
@@ -1362,13 +1461,13 @@ class TranslationServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.translate_v3beta1.types.DeleteGlossaryRequest, dict]):
+            request (Optional[Union[google.cloud.translate_v3beta1.types.DeleteGlossaryRequest, dict]]):
                 The request object. Request message for DeleteGlossary.
             name (:class:`str`):
                 Required. The name of the glossary to
@@ -1459,14 +1558,9 @@ class TranslationServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-translate",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("TranslationServiceAsyncClient",)
